@@ -12,9 +12,9 @@ import (
 	"strings"
 	"time"
 
+	"github.com/autobrr/autobrr/internal/database/migrations"
 	"github.com/autobrr/autobrr/pkg/errors"
 
-	"github.com/lib/pq"
 	_ "modernc.org/sqlite"
 )
 
@@ -30,8 +30,7 @@ func (db *DB) openSQLite() error {
 
 	// open database connection
 	if db.Handler, err = sql.Open("sqlite", db.DSN+"?_pragma=busy_timeout%3d1000"); err != nil {
-		db.log.Fatal().Err(err).Msg("could not open db connection")
-		return err
+		return errors.Wrap(err, "could not open db connection")
 	}
 
 	// Set busy timeout
@@ -80,9 +79,10 @@ func (db *DB) openSQLite() error {
 	//}
 
 	// migrate db
-	if err = db.migrateSQLite(); err != nil {
-		db.log.Fatal().Err(err).Msg("could not migrate db")
-		return err
+	if db.cfg.DatabaseAutoMigrate {
+		if err = db.migrateSQLite(); err != nil {
+			return errors.Wrap(err, "could not migrate db")
+		}
 	}
 
 	return nil
@@ -104,36 +104,12 @@ func (db *DB) closingSQLite() error {
 }
 
 func (db *DB) migrateSQLite() error {
-	db.lock.Lock()
-	defer db.lock.Unlock()
-
-	var version int
-	if err := db.Handler.QueryRow("PRAGMA user_version").Scan(&version); err != nil {
-		return errors.Wrap(err, "failed to query schema version")
-	}
-
-	if version == len(sqliteMigrations) {
-		return nil
-	} else if version > len(sqliteMigrations) {
-		return errors.New("autobrr (version %d) older than schema (version: %d)", len(sqliteMigrations), version)
-	}
-
-	db.log.Info().Msgf("Beginning database schema upgrade from version %d to version: %d", version, len(sqliteMigrations))
-
-	tx, err := db.Handler.Begin()
-	if err != nil {
-		return err
-	}
-	defer tx.Rollback()
-
-	if version == 0 {
-		if _, err := tx.Exec(sqliteSchema); err != nil {
-			return errors.Wrap(err, "failed to initialize schema")
-		}
-	} else {
+	migrate := migrations.SQLiteMigrations(db.Handler, db.log)
+	migrate.PreMigrationHook = func() error {
 		if db.cfg.DatabaseMaxBackups > 0 {
 			if err := db.databaseConsistencyCheckSQLite(); err != nil {
 				return errors.Wrap(err, "database image malformed")
+
 			}
 
 			if err := db.backupSQLiteDatabase(); err != nil {
@@ -141,36 +117,13 @@ func (db *DB) migrateSQLite() error {
 			}
 		}
 
-		for i := version; i < len(sqliteMigrations); i++ {
-			db.log.Info().Msgf("Upgrading Database schema to version: %v", i+1)
-
-			if _, err := tx.Exec(sqliteMigrations[i]); err != nil {
-				return errors.Wrap(err, "failed to execute migration #%v", i)
-			}
-		}
-
-		// temp custom data migration
-		// get data from filter.sources, check if specific types, move to new table and clear
-		// if migration 6
-		// TODO 2022-01-30 remove this in future version
-		if version == 5 && len(sqliteMigrations) == 6 {
-			if err := customMigrateCopySourcesToMedia(tx); err != nil {
-				return errors.Wrap(err, "could not run custom data migration")
-			}
-		}
+		return nil
 	}
 
-	_, err = tx.Exec(fmt.Sprintf("PRAGMA user_version = %d", len(sqliteMigrations)))
-	if err != nil {
-		return errors.Wrap(err, "failed to bump schema version")
+	if err := migrate.Migrate(); err != nil {
+		return errors.Wrap(err, "failed to migrate database")
 	}
 
-	if err := tx.Commit(); err != nil {
-		return errors.Wrap(err, "failed to commit migration transaction")
-	}
-
-	db.log.Info().Msgf("Database schema upgraded to version: %d", len(sqliteMigrations))
-
 	if err := db.cleanupSQLiteBackups(); err != nil {
 		return err
 	}
@@ -178,96 +131,6 @@ func (db *DB) migrateSQLite() error {
 	return nil
 }
 
-// customMigrateCopySourcesToMedia move music specific sources to media
-func customMigrateCopySourcesToMedia(tx *sql.Tx) error {
-	rows, err := tx.Query(`
-		SELECT id, sources
-		FROM filter
-		WHERE sources LIKE '%"CD"%'
-		   OR sources LIKE '%"WEB"%'
-		   OR sources LIKE '%"DVD"%'
-		   OR sources LIKE '%"Vinyl"%'
-		   OR sources LIKE '%"Soundboard"%'
-		   OR sources LIKE '%"DAT"%'
-		   OR sources LIKE '%"Cassette"%'
-		   OR sources LIKE '%"Blu-Ray"%'
-		   OR sources LIKE '%"SACD"%'
-		;`)
-	if err != nil {
-		return errors.Wrap(err, "could not run custom data migration")
-	}
-
-	defer rows.Close()
-
-	type tmpDataStruct struct {
-		id      int
-		sources []string
-	}
-
-	var tmpData []tmpDataStruct
-
-	// scan data
-	for rows.Next() {
-		var t tmpDataStruct
-
-		if err := rows.Scan(&t.id, pq.Array(&t.sources)); err != nil {
-			return err
-		}
-
-		tmpData = append(tmpData, t)
-	}
-	if err := rows.Err(); err != nil {
-		return err
-	}
-
-	// manipulate data
-	for _, d := range tmpData {
-		// create new slice with only music source if they exist in d.sources
-		mediaSources := []string{}
-		for _, source := range d.sources {
-			switch source {
-			case "CD":
-				mediaSources = append(mediaSources, source)
-			case "DVD":
-				mediaSources = append(mediaSources, source)
-			case "Vinyl":
-				mediaSources = append(mediaSources, source)
-			case "Soundboard":
-				mediaSources = append(mediaSources, source)
-			case "DAT":
-				mediaSources = append(mediaSources, source)
-			case "Cassette":
-				mediaSources = append(mediaSources, source)
-			case "Blu-Ray":
-				mediaSources = append(mediaSources, source)
-			case "SACD":
-				mediaSources = append(mediaSources, source)
-			}
-		}
-		_, err = tx.Exec(`UPDATE filter SET media = ? WHERE id = ?`, pq.Array(mediaSources), d.id)
-		if err != nil {
-			return err
-		}
-
-		// remove all music specific sources
-		cleanSources := []string{}
-		for _, source := range d.sources {
-			switch source {
-			case "CD", "WEB", "DVD", "Vinyl", "Soundboard", "DAT", "Cassette", "Blu-Ray", "SACD":
-				continue
-			}
-			cleanSources = append(cleanSources, source)
-		}
-		_, err := tx.Exec(`UPDATE filter SET sources = ? WHERE id = ?`, pq.Array(cleanSources), d.id)
-		if err != nil {
-			return err
-		}
-
-	}
-
-	return nil
-}
-
 func (db *DB) databaseConsistencyCheckSQLite() error {
 	db.log.Info().Msg("Database integrity check..")
 
