@@ -21,3 +21,20 @@ type APIKey struct {
 	Scopes    []string  `json:"scopes"`
 	CreatedAt time.Time `json:"created_at"`
 }
+
+const RedactedStr = "<redacted>"
+
+func RedactString(s string) string {
+	if len(s) == 0 {
+		return ""
+	}
+
+	return RedactedStr
+}
+
+func IsRedactedString(s string) bool {
+	if s == "" {
+		return false
+	}
+	return s == RedactedStr
+}
