@@ -6,7 +6,9 @@ package domain
 import (
 	"bytes"
 	"context"
+	"encoding/json"
 	"net/url"
+	"strings"
 	"text/template"
 
 	"github.com/autobrr/autobrr/pkg/errors"
@@ -40,6 +42,44 @@ type Indexer struct {
 	Settings           map[string]string `json:"settings,omitempty"`
 }
 
+func (i Indexer) MarshalJSON() ([]byte, error) {
+	// Define secret keys that should be redacted
+	secretKeys := map[string]bool{
+		"rsskey":       true,
+		"rss_key":      true,
+		"passkey":      true,
+		"authkey":      true,
+		"torrentpass":  true,
+		"torrent_pass": true,
+		"api_key":      true,
+		"apikey":       true,
+		"uid":          true,
+		"key":          true,
+		"token":        true,
+		"cookie":       true,
+	}
+
+	// Create a copy of the settings map with redacted secrets
+	redactedSettings := make(map[string]string)
+	for key, value := range i.Settings {
+		if secretKeys[strings.ToLower(key)] {
+			redactedSettings[key] = RedactString(value)
+		} else {
+			redactedSettings[key] = value
+		}
+	}
+
+	// Create alias type to avoid infinite recursion
+	type Alias Indexer
+	return json.Marshal(&struct {
+		*Alias
+		Settings map[string]string `json:"settings,omitempty"`
+	}{
+		Settings: redactedSettings,
+		Alias:    (*Alias)(&i),
+	})
+}
+
 func (i Indexer) ImplementationIsFeed() bool {
 	return i.Implementation == "rss" || i.Implementation == "torznab" || i.Implementation == "newznab"
 }
@@ -182,6 +222,23 @@ type IndexerSetting struct {
 	Regex       string `json:"regex,omitempty"`
 }
 
+func (is IndexerSetting) MarshalJSON() ([]byte, error) {
+	type Alias IndexerSetting
+
+	redactedValue := is.Value
+	if strings.ToLower(is.Type) == "secret" {
+		redactedValue = RedactString(is.Value)
+	}
+
+	return json.Marshal(&struct {
+		*Alias
+		Value string `json:"value,omitempty"`
+	}{
+		Value: redactedValue,
+		Alias: (*Alias)(&is),
+	})
+}
+
 type Torznab struct {
 	MinInterval int              `json:"minInterval"`
 	Settings    []IndexerSetting `json:"settings"`
