@@ -82,7 +82,7 @@ type Handler struct {
 	sse                 *sse.Server
 	network             *domain.IrcNetwork
 	releaseSvc          release.Service
-	notificationService notification.Service
+	notificationService notification.Sender
 	announceProcessors  map[string]announce.Processor
 	definitions         map[string]*domain.IndexerDefinition
 
@@ -106,7 +106,7 @@ type Handler struct {
 	saslauthed    bool
 }
 
-func NewHandler(log zerolog.Logger, sse *sse.Server, network domain.IrcNetwork, definitions []*domain.IndexerDefinition, releaseSvc release.Service, notificationSvc notification.Service) *Handler {
+func NewHandler(log zerolog.Logger, sse *sse.Server, network domain.IrcNetwork, definitions []*domain.IndexerDefinition, releaseSvc release.Service, notificationSvc notification.Sender) *Handler {
 	h := &Handler{
 		log:                 log.With().Str("network", network.Server).Logger(),
 		sse:                 sse,
@@ -382,7 +382,8 @@ func (h *Handler) isOurNick(nick string) bool {
 }
 
 func (h *Handler) isOurCurrentNick(nick string) bool {
-	return h.CurrentNick() == nick
+	// soju just reports JOIN (366) messages with the wildcard.
+	return h.CurrentNick() == nick || (h.network.UseBouncer && nick == "*")
 }
 
 func (h *Handler) setConnectionStatus() {
