@@ -108,13 +108,38 @@ func (s *ntfySender) CanSendPayload(event domain.NotificationEvent, payload doma
 		return false
 	}
 
-	if s.isEnabledEvent(event) || s.Settings.FilterEventEnabled(payload.FilterID, event) {
+	if payload.FilterID > 0 {
+		if s.Settings.FilterMuted(payload.FilterID) {
+			s.log.Trace().Str("event", string(event)).Int("filter_id", payload.FilterID).Str("filter", payload.Filter).Msg("notification muted by filter")
+			return false
+		}
+
+		// Check if the filter has custom notifications configured
+		if s.Settings.FilterEventEnabled(payload.FilterID, event) {
+			return true
+		}
+
+		// If the filter has custom notifications but the event is not enabled, don't fall back to global
+		if s.Settings.HasFilterNotifications(payload.FilterID) {
+			return false
+		}
+	}
+
+	// Fall back to global events for non-filter events or filters without custom notifications
+	if s.isEnabledEvent(event) {
 		return true
 	}
 
 	return false
 }
 
+func (s *ntfySender) HasFilterEvents(filterID int) bool {
+	if s.Settings.HasFilterNotifications(filterID) {
+		return true
+	}
+	return false
+}
+
 func (s *ntfySender) IsEnabled() bool {
 	return s.Settings.IsEnabled()
 }
